# django-odoo-auth
[![Upload Python Package](https://github.com/w0rng/django-odoo-auth/actions/workflows/python-publish.yml/badge.svg)](https://github.com/w0rng/django-odoo-auth/actions/workflows/python-publish.yml) 

Custom django auth backend for authorization via odoo
